@@ -25,6 +25,7 @@ import (
 	"bytes"
 	"context"
 	_ "embed"
+	"encoding/json"
 	"errors"
 	"fmt"
 	"sort"
@@ -34,17 +35,17 @@ import (
 
 	"github.com/docker/go-connections/nat"
 	"github.com/imdario/mergo"
+	"github.com/k3d-io/k3d/v5/pkg/actions"
+	config "github.com/k3d-io/k3d/v5/pkg/config/v1alpha4"
+	l "github.com/k3d-io/k3d/v5/pkg/logger"
+	"github.com/k3d-io/k3d/v5/pkg/runtimes"
+	k3drt "github.com/k3d-io/k3d/v5/pkg/runtimes"
+	runtimeErr "github.com/k3d-io/k3d/v5/pkg/runtimes/errors"
+	"github.com/k3d-io/k3d/v5/pkg/types"
+	k3d "github.com/k3d-io/k3d/v5/pkg/types"
+	"github.com/k3d-io/k3d/v5/pkg/types/k3s"
+	"github.com/k3d-io/k3d/v5/pkg/util"
 	copystruct "github.com/mitchellh/copystructure"
-	"github.com/rancher/k3d/v5/pkg/actions"
-	config "github.com/rancher/k3d/v5/pkg/config/v1alpha4"
-	l "github.com/rancher/k3d/v5/pkg/logger"
-	"github.com/rancher/k3d/v5/pkg/runtimes"
-	k3drt "github.com/rancher/k3d/v5/pkg/runtimes"
-	runtimeErr "github.com/rancher/k3d/v5/pkg/runtimes/errors"
-	"github.com/rancher/k3d/v5/pkg/types"
-	k3d "github.com/rancher/k3d/v5/pkg/types"
-	"github.com/rancher/k3d/v5/pkg/types/k3s"
-	"github.com/rancher/k3d/v5/pkg/util"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/sync/errgroup"
 	"gopkg.in/yaml.v2"
@@ -377,6 +378,18 @@ ClusterCreatOpts:
 	}
 	clusterCreateOpts.GlobalLabels[k3d.LabelClusterToken] = cluster.Token
 
+	/*
+	 * Extra Labels
+	 */
+	if len(clusterCreateOpts.HostAliases) > 0 {
+		hostAliasesJSON, err := json.Marshal(clusterCreateOpts.HostAliases)
+		if err != nil {
+			return fmt.Errorf("error marshalling hostaliases: %w", err)
+		}
+
+		clusterCreateOpts.GlobalLabels[k3d.LabelClusterStartHostAliases] = string(hostAliasesJSON)
+	}
+
 	/*
 	 * Nodes
 	 */
@@ -654,7 +667,7 @@ func ClusterDelete(ctx context.Context, runtime k3drt.Runtime, cluster *k3d.Clus
 	for _, vol := range cluster.Volumes {
 		l.Log().Debugf("Deleting volume %s...", vol)
 		if err := runtime.DeleteVolume(ctx, vol); err != nil {
-			l.Log().Warningf("Failed to delete volume '%s' of cluster '%s': %v -> Try to delete it manually", cluster.ImageVolume, err, cluster.Name)
+			l.Log().Warningf("Failed to delete volume '%s' of cluster '%s': %v -> Try to delete it manually", cluster.ImageVolume, cluster.Name, err)
 		}
 	}
 
@@ -762,6 +775,22 @@ func populateClusterFieldsFromLabels(cluster *k3d.Cluster) error {
 	return nil
 }
 
+func GetClusterStartOptsFromLabels(cluster *k3d.Cluster) (k3d.ClusterStartOpts, error) {
+	clusterStartOpts := k3d.ClusterStartOpts{
+		HostAliases: []k3d.HostAlias{},
+	}
+	for _, node := range cluster.Nodes {
+		if len(clusterStartOpts.HostAliases) == 0 {
+			if hostAliasesJSON, ok := node.RuntimeLabels[k3d.LabelClusterStartHostAliases]; ok {
+				if err := json.Unmarshal([]byte(hostAliasesJSON), &clusterStartOpts.HostAliases); err != nil {
+					return clusterStartOpts, fmt.Errorf("error unmarshalling hostaliases JSON from node %s label: %w", node.Name, err)
+				}
+			}
+		}
+	}
+	return clusterStartOpts, nil
+}
+
 var ClusterGetNoNodesFoundError = errors.New("No nodes found for given cluster")
 
 // ClusterGet returns an existing cluster with all fields and node lists populated
