@@ -27,8 +27,8 @@ import (
 	"time"
 
 	"github.com/docker/go-connections/nat"
-	runtimeTypes "github.com/rancher/k3d/v5/pkg/runtimes/types"
-	"github.com/rancher/k3d/v5/pkg/types/k3s"
+	runtimeTypes "github.com/k3d-io/k3d/v5/pkg/runtimes/types"
+	"github.com/k3d-io/k3d/v5/pkg/types/k3s"
 	"inet.af/netaddr"
 )
 
@@ -75,25 +75,26 @@ var ClusterExternalNodeRoles = []Role{
 
 // List of k3d technical label name
 const (
-	LabelClusterName          string = "k3d.cluster"
-	LabelClusterURL           string = "k3d.cluster.url"
-	LabelClusterToken         string = "k3d.cluster.token"
-	LabelClusterExternal      string = "k3d.cluster.external"
-	LabelImageVolume          string = "k3d.cluster.imageVolume"
-	LabelNetworkExternal      string = "k3d.cluster.network.external"
-	LabelNetwork              string = "k3d.cluster.network"
-	LabelNetworkID            string = "k3d.cluster.network.id"
-	LabelNetworkIPRange       string = "k3d.cluster.network.iprange"
-	LabelRole                 string = "k3d.role"
-	LabelServerAPIPort        string = "k3d.server.api.port"
-	LabelServerAPIHost        string = "k3d.server.api.host"
-	LabelServerAPIHostIP      string = "k3d.server.api.hostIP"
-	LabelServerIsInit         string = "k3d.server.init"
-	LabelRegistryHost         string = "k3d.registry.host"
-	LabelRegistryHostIP       string = "k3d.registry.hostIP"
-	LabelRegistryPortExternal string = "k3s.registry.port.external"
-	LabelRegistryPortInternal string = "k3s.registry.port.internal"
-	LabelNodeStaticIP         string = "k3d.node.staticIP"
+	LabelClusterName             string = "k3d.cluster"
+	LabelClusterURL              string = "k3d.cluster.url"
+	LabelClusterToken            string = "k3d.cluster.token"
+	LabelClusterExternal         string = "k3d.cluster.external"
+	LabelImageVolume             string = "k3d.cluster.imageVolume"
+	LabelNetworkExternal         string = "k3d.cluster.network.external"
+	LabelNetwork                 string = "k3d.cluster.network"
+	LabelNetworkID               string = "k3d.cluster.network.id"
+	LabelNetworkIPRange          string = "k3d.cluster.network.iprange"
+	LabelClusterStartHostAliases string = "k3d.cluster.start.hostaliases"
+	LabelRole                    string = "k3d.role"
+	LabelServerAPIPort           string = "k3d.server.api.port"
+	LabelServerAPIHost           string = "k3d.server.api.host"
+	LabelServerAPIHostIP         string = "k3d.server.api.hostIP"
+	LabelServerIsInit            string = "k3d.server.init"
+	LabelRegistryHost            string = "k3d.registry.host"
+	LabelRegistryHostIP          string = "k3d.registry.hostIP"
+	LabelRegistryPortExternal    string = "k3s.registry.port.external"
+	LabelRegistryPortInternal    string = "k3s.registry.port.internal"
+	LabelNodeStaticIP            string = "k3d.node.staticIP"
 )
 
 // DoNotCopyServerFlags defines a list of commands/args that shouldn't be copied from an existing node when adding a similar node to a cluster
